@@ -1,14 +1,21 @@
 """""
 A mixin for staff grading.
 """
-from __future__ import absolute_import
+
 
 import logging
 
 from xblock.core import XBlock
-from openassessment.assessment.api import staff as staff_api
+from openassessment.assessment.api import (
+    staff as staff_api,
+    teams as teams_api
+)
 from openassessment.assessment.errors import StaffAssessmentInternalError, StaffAssessmentRequestError
-from openassessment.workflow import api as workflow_api
+from openassessment.workflow import (
+    api as workflow_api,
+    team_api as team_workflow_api
+)
+from submissions import team_api as team_sub_api
 
 from .data_conversion import clean_criterion_feedback, create_rubric_dict, verify_assessment_parameters
 from .staff_area_mixin import require_course_staff
@@ -37,12 +44,55 @@ class StaffAssessmentMixin:
         """
         if 'submission_uuid' not in data:
             return {
-                'success': False, 'msg': self._(u"The submission ID of the submission being assessed was not found.")
+                'success': False, 'msg': self._("The submission ID of the submission being assessed was not found.")
             }
+        if self.is_team_assignment():
+            return self._team_assess(data)
+        else:
+            try:
+                assessment = staff_api.create_assessment(
+                    data['submission_uuid'],
+                    self.get_student_item_dict()["student_id"],
+                    data['options_selected'],
+                    clean_criterion_feedback(self.rubric_criteria, data['criterion_feedback']),
+                    data['overall_feedback'],
+                    create_rubric_dict(self.prompts, self.rubric_criteria_with_labels)
+                )
+                assess_type = data.get('assess_type', 'regrade')
+                self.publish_assessment_event("openassessmentblock.staff_assess", assessment, type=assess_type)
+                workflow_api.update_from_assessments(
+                    assessment["submission_uuid"],
+                    None,
+                    override_submitter_requirements=(assess_type == 'regrade')
+                )
+            except StaffAssessmentRequestError:
+                logger.warning(
+                    "An error occurred while submitting a staff assessment "
+                    "for the submission {}".format(data['submission_uuid']),
+                    exc_info=True
+                )
+                msg = self._("Your staff assessment could not be submitted.")
+                return {'success': False, 'msg': msg}
+            except StaffAssessmentInternalError:
+                logger.exception(
+                    "An error occurred while submitting a staff assessment "
+                    "for the submission {}".format(data['submission_uuid']),
+                )
+                msg = self._("Your staff assessment could not be submitted.")
+                return {'success': False, 'msg': msg}
 
+            return {'success': True, 'msg': ""}
+
+    def _team_assess(self, data):
+        """
+        Encapsulates the functionality around staff assessment for a team based assignment
+        """
         try:
-            assessment = staff_api.create_assessment(
-                data['submission_uuid'],
+            team_submission = team_sub_api.get_team_submission_from_individual_submission(data['submission_uuid'])
+            team_submission_uuid = team_submission['team_submission_uuid']
+
+            assessment = teams_api.create_assessment(
+                team_submission_uuid,
                 self.get_student_item_dict()["student_id"],
                 data['options_selected'],
                 clean_criterion_feedback(self.rubric_criteria, data['criterion_feedback']),
@@ -50,30 +100,29 @@ class StaffAssessmentMixin:
                 create_rubric_dict(self.prompts, self.rubric_criteria_with_labels)
             )
             assess_type = data.get('assess_type', 'regrade')
-            self.publish_assessment_event("openassessmentblock.staff_assess", assessment, type=assess_type)
-            workflow_api.update_from_assessments(
-                assessment["submission_uuid"],
-                None,
+            self.publish_assessment_event("openassessmentblock.staff_assess", assessment[0], type=assess_type)
+            team_workflow_api.update_from_assessments(
+                team_submission_uuid,
                 override_submitter_requirements=(assess_type == 'regrade')
             )
 
         except StaffAssessmentRequestError:
             logger.warning(
-                u"An error occurred while submitting a staff assessment "
-                u"for the submission {}".format(data['submission_uuid']),
+                "An error occurred while submitting a team assessment "
+                "for the submission {}".format(data['submission_uuid']),
                 exc_info=True
             )
-            msg = self._(u"Your staff assessment could not be submitted.")
+            msg = self._("Your team assessment could not be submitted.")
             return {'success': False, 'msg': msg}
         except StaffAssessmentInternalError:
             logger.exception(
-                u"An error occurred while submitting a staff assessment "
-                u"for the submission {}".format(data['submission_uuid']),
+                "An error occurred while submitting a team assessment "
+                "for the submission {}".format(data['submission_uuid']),
             )
-            msg = self._(u"Your staff assessment could not be submitted.")
+            msg = self._("Your team assessment could not be submitted.")
             return {'success': False, 'msg': msg}
-        else:
-            return {'success': True, 'msg': u""}
+
+        return {'success': True, 'msg': ""}
 
     @XBlock.handler
     def render_staff_assessment(self, data, suffix=''):  # pylint: disable=unused-argument
